import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import * as d3 from 'd3';
import { useData } from './useData'; // Your custom hook to load data

const width = 800;
const height = 500;
const margin = { top: 20, right: 30, bottom: 65, left: 90 };

const ScatterPlot = () => {
  const data = useData();
  const [xAttribute, setXAttribute] = useState('pace');
  const [yAttribute, setYAttribute] = useState('shooting');

  // Assuming 'data' is loaded correctly through useData hook
  useEffect(() => {
    if (!data) return;

    const svg = d3.select('#scatterPlot');
    svg.selectAll('*').remove(); // Clear SVG content before redrawing

    const xValue = (d) => d[xAttribute];
    const yValue = (d) => d[yAttribute];

    const xScale = d3
      .scaleLinear()
      .domain(d3.extent(data, xValue))
      .range([margin.left, width - margin.right]);

    const yScale = d3
      .scaleLinear()
      .domain(d3.extent(data, yValue))
      .range([height - margin.bottom, margin.top]);

    const xAxis = d3.axisBottom(xScale).ticks(6);
    svg
      .append('g')
      .attr(
        'transform',
        `translate(0,${height - margin.bottom})`,
      )
      .call(xAxis);

    const yAxis = d3.axisLeft(yScale).ticks(6);
    svg
      .append('g')
      .attr('transform', `translate(${margin.left},0)`)
      .call(yAxis);

    svg
      .selectAll('circle')
      .data(data)
      .enter()
      .append('circle')
      .attr('cx', (d) => xScale(xValue(d)))
      .attr('cy', (d) => yScale(yValue(d)))
      .attr('r', 5)
      .attr('fill', 'dodgerblue');
  }, [data, xAttribute, yAttribute]);

  // Helper function to generate options
  const attributeOptions = [
    'pace',
    'shooting',
    'passing',
    'dribbling',
    'defending',
    'physic',
  ].map((attribute) => ({
    value: attribute,
    label:
      attribute.charAt(0).toUpperCase() +
      attribute.slice(1),
  }));

  return (
    <div>
      <div>
        <label for="x-select">X Attribute: </label>
        <select
          id="x-select"
          value={xAttribute}
          onChange={(e) => setXAttribute(e.target.value)}
        >
          {attributeOptions.map((option) => (
            <option key={option.value} value={option.value}>
              {option.label}
            </option>
          ))}
        </select>
        <label for="y-select">Y Attribute: </label>
        <select
          id="y-select"
          value={yAttribute}
          onChange={(e) => setYAttribute(e.target.value)}
        >
          {attributeOptions.map((option) => (
            <option key={option.value} value={option.value}>
              {option.label}
            </option>
          ))}
        </select>
      </div>
      <svg
        id="scatterPlot"
        width={width}
        height={height}
      ></svg>
    </div>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<ScatterPlot />, rootElement);
